import React, { useState, useEffect } from 'react';
import { Link, useLocation, useNavigate } from 'react-router-dom';
import { Menu, Users } from 'lucide-react';
import { useChatStore } from '../store/chat';
import { socket } from '../lib/socket';
import { ThemeToggle } from './ThemeToggle';
import { motion, AnimatePresence, useSpring } from 'framer-motion';
import { Sidebar } from './Sidebar';
import { cn } from '../lib/utils';

interface HeaderProps {
  className?: string;
}

export const Header: React.FC<HeaderProps> = ({ className }) => {
  const location = useLocation();
  const navigate = useNavigate();
  const { realUserCount, simulatedUserCount, isConnected } = useChatStore();
  const [isSidebarOpen, setIsSidebarOpen] = useState(false);
  const [isConfirmingNavigation, setIsConfirmingNavigation] = useState(false);
  const [pendingPath, setPendingPath] = useState<string | null>(null);
  const isChatPage = location.pathname === '/chat';

  // Smooth animation for total user count
  const animatedUserCount = useSpring(realUserCount + simulatedUserCount, {
    stiffness: 100,
    damping: 20,
    mass: 0.5,
  });

  useEffect(() => {
    // Ensure we're working with valid numbers before setting the animated value
    const totalCount = Number(realUserCount) + Number(simulatedUserCount);
    if (!isNaN(totalCount)) {
      animatedUserCount.set(totalCount);
    }
  }, [realUserCount, simulatedUserCount]);
  
  useEffect(() => {
    if (isSidebarOpen) {
      document.body.style.overflow = 'hidden';
    } else {
      document.body.style.overflow = 'unset';
    }
    return () => {
      document.body.style.overflow = 'unset';
    };
  }, [isSidebarOpen]);

  React.useEffect(() => {
    if (!socket.connected) {
      socket.connect();
    }

    socket.on('online_users', (count: number) => {
      useChatStore.getState().setRealUserCount(count);
    });

    return () => {
      socket.off('online_users');
    };
  }, []);

  const handleToggleSidebar = (e: React.MouseEvent) => {
    e.stopPropagation();
    setIsSidebarOpen(prev => !prev);
  };

  const handleNavigation = (path: string, e?: React.MouseEvent) => {
    e?.preventDefault();
    if (isChatPage && isConnected) {
      setPendingPath(path);
      setIsConfirmingNavigation(true);
    } else {
      navigate(path);
    }
  };

  const handleConfirmNavigation = () => {
    if (pendingPath) {
      socket.emit('end_chat');
      navigate(pendingPath);
      setIsConfirmingNavigation(false);
      setPendingPath(null);
    }
  };

  useEffect(() => {
    setIsSidebarOpen(false);
  }, [location.pathname]);

  return (
    <>
      <header className={cn(
        'bg-white/70 dark:bg-gray-900/70 backdrop-blur-md border-b border-gray-200/50 dark:border-gray-700/50 transition-colors duration-300',
        className
      )}>
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16">
            <div className="flex items-center md:hidden">
              <button
                onClick={handleToggleSidebar}
                className="p-2 rounded-lg text-gray-600 dark:text-gray-300 hover:bg-gray-100/50 dark:hover:bg-gray-800/50 transition-colors focus-ring"
              >
                <Menu size={24} />
              </button>
            </div>

            <Link 
              to="/" 
              onClick={(e) => handleNavigation('/', e)}
              className="flex items-center"
            >
              <img 
                src="/images/logo.png" 
                alt="Meet Anon Logo" 
                className="w-14 h-14 object-contain"
              />
              <span className="text-xl font-semibold text-gray-900 dark:text-gray-100">
                Meet Anon
              </span>
            </Link>

            <nav className="hidden md:flex items-center justify-center absolute left-1/2 -translate-x-1/2 space-x-8">
              {[
                { path: '/', label: 'Home' },
                { path: '/about', label: 'About' },
                { path: '/leaderboard', label: 'Leaderboard' },
                { path: '/help', label: 'FAQ' },
                { path: '/guidelines', label: 'Guidelines' },
                { path: '/contact', label: 'Contact' }
              ].map(({ path, label }) => (
                <a
                  key={path}
                  href={path}
                  onClick={(e) => handleNavigation(path, e)}
                  className={`relative text-gray-600 dark:text-gray-300 hover:text-gray-900 dark:hover:text-white transition-colors ${
                    location.pathname === path ? 'text-blue-600 dark:text-blue-400 after:absolute after:bottom-0 after:left-0 after:w-full after:h-0.5 after:bg-blue-600 dark:after:bg-blue-400' : ''
                  }`}
                >
                  {label}
                </a>
              ))}
            </nav>

            <div className="flex items-center space-x-6">
              <motion.div 
                className="flex items-center gap-2 px-3 py-1.5 rounded-full bg-gray-100/70 dark:bg-gray-800/50 text-gray-600 dark:text-gray-300"
                initial={false}
                animate={{ scale: [1, 1.05, 1] }}
                transition={{ duration: 0.3 }}
              >
                <Users size={16} className="text-blue-600 dark:text-blue-400" />
                <motion.span 
                  className="text-sm font-medium hidden sm:inline"
                >
                  {isNaN(animatedUserCount.get()) ? '0' : String(Math.round(animatedUserCount.get()))} online
                </motion.span>
                <motion.span 
                  className="text-sm font-medium sm:hidden"
                >
                  {isNaN(animatedUserCount.get()) ? '0' : String(Math.round(animatedUserCount.get()))}
                </motion.span>
              </motion.div>
              <ThemeToggle />
            </div>
          </div>
        </div>
      </header>

      <AnimatePresence>
        {isSidebarOpen && (
          <>
            <motion.div
              initial={{ opacity: 0 }}
              animate={{ opacity: 0.5 }}
              exit={{ opacity: 0 }}
              onClick={() => setIsSidebarOpen(false)}
              className="fixed inset-0 bg-black z-40 md:hidden"
            />
            <motion.div
              initial={{ x: '-100%' }}
              animate={{ x: 0 }}
              exit={{ x: '-100%' }}
              transition={{ type: 'spring', damping: 20 }}
              className="fixed inset-y-0 left-0 w-64 bg-white dark:bg-gray-800 z-50 md:hidden overflow-y-auto"
            >
              <div className="p-4">
                <button
                  onClick={() => setIsSidebarOpen(false)}
                  className="absolute top-2 right-2 p-2 text-gray-500 hover:text-gray-700 dark:text-gray-400 dark:hover:text-gray-200"
                >
                  <Menu size={20} />
                </button>
                <Sidebar onClose={() => setIsSidebarOpen(false)} />
              </div>
            </motion.div>
          </>
        )}

        {isConfirmingNavigation && (
          <>
            <motion.div
              initial={{ opacity: 0 }}
              animate={{ opacity: 1 }}
              exit={{ opacity: 0 }}
              className="fixed inset-0 bg-black/50 backdrop-blur-sm z-50"
              onClick={() => setIsConfirmingNavigation(false)}
            />
            <div className="fixed inset-0 flex items-center justify-center z-50 p-4">
              <motion.div
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                exit={{ opacity: 0, y: 20 }}
                className="w-full max-w-md bg-gray-900/95 backdrop-blur-xl rounded-2xl shadow-xl border border-gray-700/50"
              >
                <div className="p-6 space-y-4">
                  <h3 className="text-xl font-semibold text-white">
                    Leave Chat?
                  </h3>
                  <p className="text-gray-300">
                    You are currently connected with a partner. Are you sure you want to leave? This will end your chat session.
                  </p>
                  <div className="flex flex-row-reverse gap-3 pt-2">
                    <button
                      onClick={handleConfirmNavigation}
                      className="px-4 py-2 text-sm font-medium text-white bg-gradient-to-r from-red-500 to-pink-500 hover:from-red-600 hover:to-pink-600 rounded-lg transition-all duration-200 shadow-lg hover:shadow-xl"
                    >
                      Leave Chat
                    </button>
                    <button
                      onClick={() => setIsConfirmingNavigation(false)}
                      className="px-4 py-2 text-sm font-medium text-gray-300 bg-gray-800 hover:bg-gray-700 rounded-lg transition-colors border border-gray-700 hover:border-gray-600"
                    >
                      Cancel
                    </button>
                  </div>
                </div>
              </motion.div>
            </div>
          </>
        )}
      </AnimatePresence>
    </>
  );
};